[ostree] static-delta: increase threshold for rollsum to 50%



commit 439e1c1b9750ef5c5b4b09783ad453543217bcb5
Author: Giuseppe Scrivano <gscrivan redhat com>
Date:   Tue Feb 24 12:16:46 2015 +0100

    static-delta: increase threshold for rollsum to 50%
    
    It favours bsdiff usage for files that are not very rollsum friendly.
    
    Signed-off-by: Giuseppe Scrivano <gscrivan redhat com>

 .../ostree-repo-static-delta-compilation.c         |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/libostree/ostree-repo-static-delta-compilation.c 
b/src/libostree/ostree-repo-static-delta-compilation.c
index 968b460..a4e7ae4 100644
--- a/src/libostree/ostree-repo-static-delta-compilation.c
+++ b/src/libostree/ostree-repo-static-delta-compilation.c
@@ -568,10 +568,10 @@ try_content_rollsum (OstreeRepo                       *repo,
 
   { guint match_ratio = (matches->bufmatches*100)/matches->total;
 
     /* Only proceed if the file contains (arbitrary) more than 25% of
      * the previous chunks.
      */
-    if (match_ratio < 25)
+    if (match_ratio < 50)
       {
         ret = TRUE;
         goto out;
@@ -568,10 +568,10 @@ try_content_rollsum (OstreeRepo                       *repo,
   { guint match_ratio = (matches->bufmatches*100)/matches->total;
 
-    /* Only proceed if the file contains (arbitrary) more than 25% of
+    /* Only proceed if the file contains (arbitrary) more than 50% of
      * the previous chunks.
      */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]